@@ -1,5 +1,5 @@
 from .bot import SignalBot
-from .command import Command, CommandError
+from .command import Command, CommandError, triggered
 from .message import Message, MessageType, UnknownMessageFormatError
 from .api import SignalAPI, ReceiveMessagesError, SendMessageError
 from .context import Context
@@ -8,6 +8,7 @@ __all__ = [
     "SignalBot",
     "Command",
     "CommandError",
+    "triggered",
     "Message",
     "MessageType",
     "UnknownMessageFormatError",
